/*

  DeepBlue Starter Kit - version 1.1
  Copyright (c) 2015 INMAGIK SRL - www.inmagik.com
  All rights reserved

  written by Mauro Bianchi
  bianchimro@gmail.com  
  
  file: app.js
  
*/

angular.module('deepBlue', ['ionic', 'ngCordova', 'deepBlue.controllers', 'deepBlue.services'])

.run(function($ionicPlatform, $rootScope, $timeout, $state) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(true);
    }
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }

    /* 
      #SIMPLIFIED-IMPLEMENTATION:
      Example access control.
      A real app would probably call a service method to check if there
      is a logged user.

      #IMPLEMENTATION-DETAIL: views that require authorizations have an
      "auth" key with value = "true".
    */
    $rootScope.$on('$stateChangeStart', 
      function(event, toState, toParams, fromState, fromParams){
        if(toState.data && toState.data.auth == true && !$rootScope.user.email){
          event.preventDefault();
          $state.go('app.login');   
        }
    });

  });
})

.config(function($stateProvider, $urlRouterProvider) {

  /*

    Here we setup the views of our app.
    In this case:
    - feed, account, shop, checkout, cart will require login
    - app will go to the "start view" when launched.

    #IMPLEMENTATION-DETAIL: views that require authorizations have an
    "auth" key with value = "true".

  */
  
  $stateProvider

  .state('app', {
    url: '/app',
    abstract: true,
    templateUrl: 'templates/menu.html',
    controller: 'AppCtrl'
  })
  
  // .state('app.start', {
  //   url: '/start',
  //   views: {
  //     'menuContent': {
  //       templateUrl: 'templates/start.html'
  //     }
  //   }
  // })

  .state('app.Login', {
    cache: false,
    url: '/Login',
    cached : false,
    views: {
      'menuContent': {
        templateUrl: 'templates/Login.html',
        controller : 'LoginCtrl'
      }
    }
  })

  .state('app.forgot', {
    url: '/forgot',
    views: {
      'menuContent': {
        templateUrl: 'templates/forgot.html'
      }
    }
  })

  .state('app.signup', {
    url: '/signup',
    views: {
      'menuContent': {
        templateUrl: 'templates/signup.html'
      }
    }
  })

   .state('app.account', {
    url: '/account',
    views: {
      'menuContent': {
        templateUrl: 'templates/account.html',
        controller : 'AccountCtrl'
      }
    }
  })

  .state('app.Dashboard', {
    cache: false,
      url: '/Dashboard',
      views: {
        'menuContent': {
          templateUrl: 'templates/Dashboard.html',
          controller : 'DashboardCtrl'
        }
      }
  })

  .state('app.Bonuses', {
    cache: false,
      url: '/Bonuses',
      views: {
        'menuContent': {
          templateUrl: 'templates/Bonuses.html',
          controller : 'BonusesCtrl'
        }
      }
  })
  
  .state('app.viewCommission', {
    cache: false,
      url: '/viewCommission',
      views: {
        'menuContent': {
          templateUrl: 'templates/viewCommission.html',
          controller : 'viewCommissionCtrl'
        }
      }
  })

  .state('app.referrerCommission', {
    cache: false,
      url: '/referrerCommission',
      views: {
        'menuContent': {
          templateUrl: 'templates/referrerCommission.html',
          controller : 'referrerCommissionCtrl'
        }
      }
  })
  
  .state('app.Prospect', {
    cache: false,
      url: '/Prospect',
      views: {
        'menuContent': {
          templateUrl: 'templates/Prospect.html',
          controller : 'ProspectCtrl'
        }
      }
  })

  .state('app.ShareProspect', {
    cache: false,
      url: '/ShareProspect/:referrerId',
      views: {
        'menuContent': {
          templateUrl: 'templates/ShareProspect.html',
          controller : 'ShareProspectCtrl'
        }
      }
  })

  .state('app.Refferer', {
    cache: false,
      url: '/Refferer',
      views: {
        'menuContent': {
          templateUrl: 'templates/Refferer.html',
          controller : 'ReffererCtrl'
        }
      }
  })

  .state('app.shareRefferer', {
    cache: false,
      url: '/shareRefferer/:referrerId',
      views: {
        'menuContent': {
          templateUrl: 'templates/Share.html',
          controller : 'shareReffererCtrl'
        }
      }
  })

  .state('app.Property', {
    cache: false,
      url: '/Property',
      views: {
        'menuContent': {
          templateUrl: 'templates/Property.html',
          controller : 'PropertyCtrl'
        }
      }
  }) 

  .state('app.PropertiesonMap', {
    cache: false,
      url: '/PropertiesonMap',
      views: {
        'menuContent': {
          templateUrl: 'templates/PropertiesonMap.html',
          controller : 'PropertiesonMapCtrl'
        }
      }
  })

  .state('app.ProspectDetail', {
    cache: false,
      url: '/ProspectDetail/:ProspectId',
      views: {
        'menuContent': {
          templateUrl: 'templates/ProspectDetail.html',
          controller : 'ProspectDetailCtrl'
        }
      }
  })

  .state('app.ReffererDetail', {
    cache: false,
      url: '/ReffererDetail/:ReffererId',
      views: {
        'menuContent': {
          templateUrl: 'templates/ReffererDetail.html',
          controller : 'ReffererDetailCtrl'
        }
      }
  })

  .state('app.PropertyDetail', {
    cache: false,
      url: '/PropertyDetail/:PropertyId',
      views: {
        'menuContent': {
          templateUrl: 'templates/PropertyDetail.html',
          controller : 'PropertyDetailCtrl'
        }
      }
  }) 
  
  .state('app.PropertyCommission', {
    cache: false,
      url: '/PropertyCommission/:PropertyId',
      views: {
        'menuContent': {
          templateUrl: 'templates/PropertyCommission.html',
          controller : 'PropertyCommissionCtrl'
        }
      }
  })

  .state('app.AddProspect', {
    cache: false,
      url: '/AddProspect',
      views: {
        'menuContent': {
          templateUrl: 'templates/AddProspect.html',
          controller : 'AddProspectCtrl'
        }
      }
  }) 

  .state('app.AddRefferer', {
    cache: false,
      url: '/AddRefferer',
      views: {
        'menuContent': {
          templateUrl: 'templates/AddRefferer.html',
          controller : 'AddReffererCtrl'
        }
      }
  }) 

  .state('app.RegisterReferrer', {
    cache: false,
      url: '/RegisterReferrer',
      views: {
        'menuContent': {
          templateUrl: 'templates/RegisterReferrer.html',
          controller : 'RegisterReferrerCtrl'
        }
      }
  }) 

  .state('app.ForgotPassword', {
    cache: false,
      url: '/ForgotPassword',
      views: {
        'menuContent': {
          templateUrl: 'templates/ForgotPassword.html',
          controller : 'ForgotPasswordCtrl'
        }
      }
  }) 

  .state('app.AddProperty', {
    cache: false,
      url: '/AddProperty',
      views: {
        'menuContent': {
          templateUrl: 'templates/AddProperty.html',
          controller : 'AddPropertyCtrl'
        }
      }
  }) 

  .state('app.Contact', {
    cache: false,
      url: '/Contact',
      views: {
        'menuContent': {
          templateUrl: 'templates/Contact.html',
          controller : 'ContactCtrl'
        }
      }
  }) 
  
  .state('app.mentor', {
    cache: false,
    url: '/mentor',
    views: {
      'menuContent': {
        templateUrl: 'templates/mentor.html',
          controller : 'MentorCtrl'
      }
    }
    })
  .state('app.resources', {
    cache: false,
    url: '/resources',
    views: {
      'menuContent': {
        templateUrl: 'templates/resources.html'
      }
    }
    })
  .state('app.sliderpage', {
    cache: false,
    url: '/sliderpage',
    views: {
      'menuContent': {
        templateUrl: 'templates/sliderpage.html',
        controller: 'sliderpageCtrl'
      }
    }
    })
  // .state('app.shop', {
  //   url: '/shop',
  //   data : { auth : true },
  //   cache : false,
  //   views: {
  //     'menuContent': {
  //       templateUrl: 'templates/shop.html',
  //       controller : 'ShopCtrl'
  //     }
  //   }
  // })

  
  // If none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/app/Login');

})
.directive('qrcode', function($interpolate) {  
  return {
    restrict: 'E',
    link: function($scope, $element, $attrs) {

      var options = {
        text: '',
        width: 180,
        height: 180,
        colorDark: '#000000',
        colorLight: '#ffffff',
        correctLevel: 'H'
      };

      Object.keys(options).forEach(function(key) {
        options[key] = $interpolate($attrs[key] || '')($scope) || options[key];
      });

      options.correctLevel = QRCode.CorrectLevel[options.correctLevel];

      new QRCode($element[0], options);

    }
  }
});
